@@ -6,10 +6,13 @@ from ..helpers.params import get_profiles
 from .sym import sym
 
 
-@sym.command(short_help="list available resource groups")
+@sym.command(short_help="List available resource groups")
 @require_login
 def resources() -> None:
-    """List resource groups available for use"""
+    """List resource groups available for use.
+
+    Default resource is marked with an asterisk (*) if set.
+    """
     default = Config.instance().get("default_resource")
     for (slug, profile) in get_profiles().items():
         star = "* " if default == slug else ""
