@@ -1,13 +1,15 @@
 import json
 import re
+import shlex
 from contextlib import contextmanager
 from functools import wraps
 from pathlib import Path
 from textwrap import dedent
+from typing import Sequence
 
 import boto3
 from botocore.config import Config as BotoConfig
-from botocore.exceptions import ClientError, ConnectionError, WaiterError
+from botocore.exceptions import ClientError, ConnectionError, ProfileNotFound, WaiterError
 
 from ..decorators import retry
 from ..errors import BotoError, CliError, OfflineError
@@ -38,6 +40,13 @@ def intercept_boto_errors(f):
                 )
 
             raise CliError(str(err)) from err
+        except ProfileNotFound as err:
+            raise BotoError(
+                err,
+                "AWS profile specified could not be found. "
+                "Please check your `AWS_PROFILE` environment variable and "
+                "your credentials file (default: $HOME/.aws/credentials).",
+            )
 
     return wrapped
 
@@ -110,7 +119,7 @@ def get_identity(saml_client) -> dict:
 
 @contextmanager
 @intercept_boto_errors
-def ssm_session(saml_client, instance: str, port: int):
+def ssm_ssh_session(saml_client, instance: str, port: int):
     ssm_client = boto_client(saml_client, "ssm")
     saml_client.dprint("SSM Session: ", instance=instance)
     params = {
@@ -124,6 +133,40 @@ def ssm_session(saml_client, instance: str, port: int):
         json.dumps(response),
         ssm_client.meta.region_name,
         "StartSession",
+        # This is the profile name, left empty since we're supplying credentials via environment
+        "",
+        json.dumps(params),
+        ssm_client.meta.endpoint_url,
+    ]
+    try:
+        yield command
+    finally:
+        ssm_client.terminate_session(SessionId=response["SessionId"])
+
+
+@contextmanager
+@intercept_boto_errors
+def ssm_interactive_command(saml_client, instance: str, user: str, cmd: Sequence[str]):
+    ssm_client = boto_client(saml_client, "ssm")
+    saml_client.dprint("SSM Session: ", instance=instance)
+
+    full_cmd = f"sudo su -l {user}"
+    if len(cmd) > 0:
+        joined = shlex.join(cmd)
+        full_cmd += f' -c "{joined}"'
+
+    params = {
+        "Target": instance,
+        "DocumentName": "AWS-StartInteractiveCommand",
+        "Parameters": {"command": [f"{full_cmd}"]},
+    }
+    response = ssm_client.start_session(**params)
+    command = [
+        "session-manager-plugin",
+        json.dumps(response),
+        ssm_client.meta.region_name,
+        "StartSession",
+        # This is the profile name, left empty since we're supplying credentials via environment
         "",
         json.dumps(params),
         ssm_client.meta.endpoint_url,
