@@ -4,6 +4,8 @@ from typing import Any, Callable, ClassVar, List
 from click import Command, Context, Group
 from sentry_sdk.api import push_scope
 
+from sym.cli.helpers.global_options import GlobalOptions
+
 from ..errors import get_active_env_vars
 from ..saml_clients.chooser import choose_saml_client
 from . import segment
@@ -19,7 +21,10 @@ class AutoTagCommand(Command):
 
     def invoke(self, ctx: Context) -> Any:
         segment.track(
-            "Command Executed", command=ctx.info_name, options=ctx.obj.to_dict()
+            "Command Executed",
+            global_options=ctx.find_object(GlobalOptions),
+            command=ctx.info_name,
+            options=ctx.obj.to_dict(),
         )
         with push_scope() as scope:
             scope.set_tag("command", ctx.info_name)
@@ -59,9 +64,11 @@ class SymGroup(Group):
     """
 
     tees: ClassVar[List[Tee]] = []
+    instances = []
 
     def __init__(self, *args: Any, **attrs: Any) -> None:
         super().__init__(*args, **attrs)
+        SymGroup.instances.append(self)
 
     def __del__(self):
         self.__class__.reset_tees()
