@@ -4,7 +4,7 @@ from functools import cached_property
 from pathlib import Path
 from typing import Iterator, Tuple
 
-from ..decorators import intercept_errors, require_bins, run_subprocess
+from ..decorators import command_require_bins, intercept_errors, run_subprocess
 from ..helpers.boto import get_identity
 from ..helpers.contexts import push_env
 from ..helpers.keywords_to_options import Argument
@@ -45,7 +45,7 @@ class AwsProfile(SAMLClient):
 
     @intercept_errors()
     @run_subprocess
-    @require_bins(binary)
+    @command_require_bins(binary)
     def _exec(self, *args: str, **opts: str) -> Iterator[Tuple[Argument, ...]]:
         self.log_subprocess_event(args)
         with push_env("AWS_PROFILE", self.resource):
