@@ -9,12 +9,14 @@ from pathlib import Path
 from typing import ClassVar, Optional, Sequence, Type
 from urllib.parse import urlsplit
 
-from ..errors import CliError
-from ..helpers import segment, validations
-from ..helpers.config import SymConfigFile
-from ..helpers.keywords_to_options import keywords_to_options
-from ..helpers.os import read_write_lock
-from ..helpers.params import Profile, get_aws_saml_url, get_profile
+from policyuniverse.arn import ARN
+
+from sym.cli.errors import CliError
+from sym.cli.helpers import segment, validations
+from sym.cli.helpers.config import SymConfigFile
+from sym.cli.helpers.keywords_to_options import keywords_to_options
+from sym.cli.helpers.os import read_write_lock
+from sym.cli.helpers.params import Profile, get_aws_saml_url, get_profile
 
 
 class SAMLClient(ABC):
@@ -41,6 +43,7 @@ class SAMLClient(ABC):
         self._checked_setup = False
 
         self.check_is_setup()
+        options.saml_clients[resource] = self
 
     @property
     def _section_name(self):
@@ -75,7 +78,10 @@ class SAMLClient(ABC):
 
     @classmethod
     def sorted_subclasses(cls):
-        return sorted(cls.__subclasses__(), key=attrgetter("priority"), reverse=True)
+        filtered_subclasses = [
+            c for c in cls.__subclasses__() if "Test" not in c.__name__
+        ]
+        return sorted(filtered_subclasses, key=attrgetter("priority"), reverse=True)
 
     @abstractmethod
     def _exec(self, *args: str, **opts: str) -> None:
@@ -107,7 +113,13 @@ class SAMLClient(ABC):
 
     def _ensure_session(self, *, force: bool):
         self.dprint(f"ensuring session, force={force}")
-        self._exec("true", silence_stderr_=False, suppress_=True)
+        self._exec(
+            "true",
+            silence_stderr_=False,
+            suppress_=True,
+            run_subprocess_options_=self.options,
+            intercept_errors_options_=self.options,
+        )
 
     def ensure_session(self, force=False):
         if not self._session_exists:
@@ -137,7 +149,7 @@ class SAMLClient(ABC):
             config.write(sys.stderr)
 
     def log_subprocess_event(self, command: tuple):
-        segment.track("Subprocess Called", binary=command[0])
+        segment.track("Subprocess Called", global_options=self.options, binary=command[0])
 
     def get_profile(self) -> Profile:
         try:
@@ -166,7 +178,13 @@ class SAMLClient(ABC):
         )
 
     def get_creds(self):
-        output = self._exec("env", capture_output_=True, censor_=True)[-1]
+        output = self._exec(
+            "env",
+            capture_output_=True,
+            censor_=True,
+            run_subprocess_options_=self.options,
+            intercept_errors_options_=self.options,
+        )[-1]
         env_vars = re.findall(r"([\w_]+)=(.+)\n", output)
         return {k: v for k, v in env_vars if k in self._cred_env_vars}
 
@@ -183,10 +201,45 @@ class SAMLClient(ABC):
             return remaining < buffer
         return False
 
+    def _profile_matches_caller_identity(self):
+        from sym.cli.helpers.boto import get_identity
+
+        caller_identity = get_identity(self)
+        caller_resource = self.resource_from_arn(caller_identity["Arn"])
+        caller_role = caller_resource
+        if "/" in caller_role:
+            caller_role = caller_role.split("/", 2)[0]
+
+        profile = self.get_profile()
+        profile_role = self.resource_from_arn(profile.arn) if profile.arn else None
+
+        self.dprint(f"*** Caller Role Name: {caller_role}")
+        self.dprint(f"*** Profile Role Name: {profile_role}")
+
+        if caller_role != profile_role:
+            self.dprint(f"*** Caller identity does not match profile user!")
+            return False
+
+        return True
+
+    def resource_from_arn(self, arn):
+        if not arn:
+            raise ValueError("SAMLClient missing ARN")
+
+        name = ARN(arn).name
+        if "/" in name:
+            name = name.split("/", 1)[1]
+        elif ":" in name:
+            name = name.split(":", 1)[1]
+        return name
+
     def write_creds(self, *, path: Path, profile: str):
         self.dprint(f"writing creds, profile={profile}")
 
-        if self._creds_expiring(buffer=timedelta(minutes=5)):
+        if (
+            self._creds_expiring(buffer=timedelta(minutes=5))
+            or not self._profile_matches_caller_identity()
+        ):
             self._ensure_session(force=True)
 
         creds = self.get_creds()
