@@ -25,7 +25,10 @@ def test_resources(click_setup):
     with click_setup() as runner:
         result = runner.invoke(click_command, ["resources"])
         assert result.exit_code == 0
-        assert result.output == "test (Test)\ntest-custom (TestCustom)\n"
+        assert (
+            result.output
+            == "test (Test)\ntest_euw1 (Test: EU West 1)\ntest-custom (TestCustom)\n"
+        )
 
 
 def test_exec(click_setup, saml_client):
